# REL07-BP01: Use automation when obtaining or scaling resources

## Description

Implement auto-scaling để respond to demand changes.

## Implementation Guidance

- Configure horizontal auto-scaling
- Set scaling policies (CPU, memory, custom metrics)
- Define min/max instance counts
- Test scaling behavior under load
- Monitor scaling events

## Risk Level

High - Manual scaling is too slow for demand spikes.

## Related Best Practices

- [REL07-BP03](REL07-BP03-Predictive-Scaling.md)
- [REL06-BP04](../REL06-Change-Resource-Monitoring/REL06-BP04-Automate-Responses.md)
